pub struct FusedOutput<P: ReferenceProfile> {
pub public_key: PublicKey<P>,
pub signature: Signature<P>,
}Expand description
Output produced by a constant-work fused sign-and-public-key operation.
Fields
public_key: PublicKey<P>Public key derived from the same private key used for this signature.
signature: Signature<P>Signature captured while every chain is advanced to its endpoint.